pub enum MonitoredResource {
AppEngine {
project_id: String,
module_id: Option<String>,
version_id: Option<String>,
zone: Option<String>,
},
CloudFunction {
project_id: String,
function_name: Option<String>,
region: Option<String>,
},
CloudRunJob {
project_id: String,
job_name: Option<String>,
location: Option<String>,
},
CloudRunRevision {
project_id: String,
service_name: Option<String>,
revision_name: Option<String>,
location: Option<String>,
configuration_name: Option<String>,
},
ComputeEngine {
project_id: String,
instance_id: Option<String>,
zone: Option<String>,
},
KubernetesEngine {
project_id: String,
location: Option<String>,
cluster_name: Option<String>,
namespace_name: Option<String>,
pod_name: Option<String>,
container_name: Option<String>,
},
GenericNode {
project_id: String,
location: Option<String>,
namespace: Option<String>,
node_id: Option<String>,
},
GenericTask {
project_id: String,
location: Option<String>,
namespace: Option<String>,
job: Option<String>,
task_id: Option<String>,
},
Global {
project_id: String,
},
}The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
A description of a MonitoredResource.
Possible values are listed in the API documentation. Please submit an issue or pull request if you want to use a resource type not listed here.
Variants
AppEngine
The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Fields
project_id: StringThe opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
module_id: Option<String>The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
version_id: Option<String>The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
zone: Option<String>The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
CloudFunction
The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Fields
project_id: StringThe opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
function_name: Option<String>The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
region: Option<String>The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
CloudRunJob
The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Fields
project_id: StringThe opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
job_name: Option<String>The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
location: Option<String>The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
CloudRunRevision
The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Fields
project_id: StringThe opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
service_name: Option<String>The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
revision_name: Option<String>The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
location: Option<String>The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
configuration_name: Option<String>The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
ComputeEngine
The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Fields
project_id: StringThe opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
instance_id: Option<String>The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
zone: Option<String>The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
KubernetesEngine
The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Fields
project_id: StringThe opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
location: Option<String>The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
cluster_name: Option<String>The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
namespace_name: Option<String>The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
pod_name: Option<String>The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
container_name: Option<String>The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
GenericNode
The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Fields
project_id: StringThe opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
location: Option<String>The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
namespace: Option<String>The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
node_id: Option<String>The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
GenericTask
The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Fields
project_id: StringThe opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
location: Option<String>The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
namespace: Option<String>The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
job: Option<String>The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
task_id: Option<String>The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Global
The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Fields
project_id: StringThe opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.