Module api

Module api 

👎Deprecated since 0.30.0:

The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.

Modules

http_ruleDeprecated
Nested message and enum types in HttpRule.
label_descriptorDeprecated
Nested message and enum types in LabelDescriptor.
method_settingsDeprecated
Nested message and enum types in MethodSettings.
python_settingsDeprecated
Nested message and enum types in PythonSettings.
resource_descriptorDeprecated
Nested message and enum types in ResourceDescriptor.

Structs

ClientLibrarySettingsDeprecated
Details about how and where to publish client libraries.
CommonLanguageSettingsDeprecated
Required information for every language.
CppSettingsDeprecated
Settings for C++ client libraries.
CustomHttpPatternDeprecated
A custom pattern is used for defining custom HTTP verb.
DotnetSettingsDeprecated
Settings for Dotnet client libraries.
GoSettingsDeprecated
Settings for Go client libraries.
HttpDeprecated
Defines the HTTP configuration for an API service. It contains a list of [HttpRule][google.api.HttpRule], each specifying the mapping of an RPC method to one or more HTTP REST API methods.
HttpRuleDeprecated
gRPC Transcoding
JavaSettingsDeprecated
Settings for Java client libraries.
LabelDescriptorDeprecated
A description of a label.
MethodSettingsDeprecated
Describes the generator configuration for a method.
MonitoredResourceDeprecated
An object representing a resource that can be used for monitoring, logging, billing, or other purposes. Examples include virtual machine instances, databases, and storage devices such as disks. The type field identifies a [MonitoredResourceDescriptor][google.api.MonitoredResourceDescriptor] object that describes the resource’s schema. Information in the labels field identifies the actual resource and its attributes according to the schema. For example, a particular Compute Engine VM instance could be represented by the following object, because the [MonitoredResourceDescriptor][google.api.MonitoredResourceDescriptor] for "gce_instance" has labels "project_id", "instance_id" and "zone":
MonitoredResourceDescriptorDeprecated
An object that describes the schema of a [MonitoredResource][google.api.MonitoredResource] object using a type name and a set of labels. For example, the monitored resource descriptor for Google Compute Engine VM instances has a type of "gce_instance" and specifies the use of the labels "instance_id" and "zone" to identify particular VM instances.
MonitoredResourceMetadataDeprecated
Auxiliary metadata for a [MonitoredResource][google.api.MonitoredResource] object. [MonitoredResource][google.api.MonitoredResource] objects contain the minimum set of information to uniquely identify a monitored resource instance. There is some other useful auxiliary metadata. Monitoring and Logging use an ingestion pipeline to extract metadata for cloud resources of all types, and store the metadata in this message.
NodeSettingsDeprecated
Settings for Node client libraries.
PhpSettingsDeprecated
Settings for Php client libraries.
PublishingDeprecated
This message configures the settings for publishing Google Cloud Client libraries generated from the service config.
PythonSettingsDeprecated
Settings for Python client libraries.
ResourceDescriptorDeprecated
A simple descriptor of a resource type.
ResourceReferenceDeprecated
Defines a proto annotation that describes a string field that refers to an API resource.
RubySettingsDeprecated
Settings for Ruby client libraries.
SelectiveGapicGenerationDeprecated
This message is used to configure the generation of a subset of the RPCs in a service for client libraries.

Enums

ClientLibraryDestinationDeprecated
To where should client libraries be published?
ClientLibraryOrganizationDeprecated
The organization for which the client libraries are being published. Affects the url where generated docs are published, etc.
FieldBehaviorDeprecated
An indicator of the behavior of a given field (for example, that a field is required in requests, or given as output but ignored as input). This does not change the behavior in protocol buffers itself; it only denotes the behavior and may affect how API tooling handles the field.
LaunchStageDeprecated
The launch stage as defined by Google Cloud Platform Launch Stages.