pub struct ExperimentalFeatures {
pub rest_async_io_enabled: bool,
pub protobuf_pythonic_types_enabled: bool,
pub unversioned_package_disabled: bool,
}The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Experimental features to be included during client library generation. These fields will be deprecated once the feature graduates and is enabled by default.
Fields
rest_async_io_enabled: boolThe opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Enables generation of asynchronous REST clients if rest transport is
enabled. By default, asynchronous REST clients will not be generated.
This feature will be enabled by default 1 month after launching the
feature in preview packages.
protobuf_pythonic_types_enabled: boolThe opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Enables generation of protobuf code using new types that are more
Pythonic which are included in protobuf>=5.29.x. This feature will be
enabled by default 1 month after launching the feature in preview
packages.
unversioned_package_disabled: boolThe opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Disables generation of an unversioned Python package for this client
library. This means that the module names will need to be versioned in
import statements. For example import google.cloud.library_v2 instead
of import google.cloud.library.