Module resource_descriptor

Module resource_descriptor 

๐Ÿ‘ŽDeprecated since 0.30.0:

The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.

Nested message and enum types in ResourceDescriptor.

Enums

HistoryDeprecated
A description of the historical or future-looking state of the resource pattern.
StyleDeprecated
A flag representing a specific style that a resource claims to conform to.