pub struct CommonLanguageSettings {
pub reference_docs_uri: String,
pub destinations: Vec<i32>,
pub selective_gapic_generation: Option<SelectiveGapicGeneration>,
}The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Required information for every language.
Fields
reference_docs_uri: StringLink to automatically generated reference documentation. Example: https://cloud.google.com/nodejs/docs/reference/asset/latest
destinations: Vec<i32>The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
The destination where API teams want this client library to be published.
selective_gapic_generation: Option<SelectiveGapicGeneration>The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Configuration for which RPCs should be generated in the GAPIC client.
Implementations
Sourceimpl CommonLanguageSettings
impl CommonLanguageSettings
Sourcepub fn destinations(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<ClientLibraryDestination>>
๐Deprecated since 0.30.0: The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
pub fn destinations( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<ClientLibraryDestination>>
The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Returns an iterator which yields the valid enum values contained in destinations.
Sourcepub fn push_destinations(&mut self, value: ClientLibraryDestination)
๐Deprecated since 0.30.0: The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
pub fn push_destinations(&mut self, value: ClientLibraryDestination)
The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Appends the provided enum value to destinations.