GoSettings

Struct GoSettings 

pub struct GoSettings {
    pub common: Option<CommonLanguageSettings>,
    pub renamed_services: HashMap<String, String>,
}
๐Ÿ‘ŽDeprecated since 0.30.0:

The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.

Settings for Go client libraries.

Fields

common: Option<CommonLanguageSettings>
๐Ÿ‘ŽDeprecated since 0.30.0:

The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.

Some settings.

renamed_services: HashMap<String, String>
๐Ÿ‘ŽDeprecated since 0.30.0:

The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.

Map of service names to renamed services. Keys are the package relative service names and values are the name to be used for the service client and call options.

publishing: go_settings: renamed_services: Publisher: TopicAdmin