pub struct Http {
pub rules: Vec<HttpRule>,
pub fully_decode_reserved_expansion: bool,
}The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Defines the HTTP configuration for an API service. It contains a list of [HttpRule][google.api.HttpRule], each specifying the mapping of an RPC method to one or more HTTP REST API methods.
Fields
rules: Vec<HttpRule>The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
A list of HTTP configuration rules that apply to individual API methods.
NOTE: All service configuration rules follow โlast one winsโ order.
fully_decode_reserved_expansion: boolThe opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
When set to true, URL path parameters will be fully URI-decoded except in cases of single segment matches in reserved expansion, where โ%2Fโ will be left encoded.
The default behavior is to not decode RFC 6570 reserved characters in multi segment matches.