pub struct JavaSettings {
pub library_package: String,
pub service_class_names: HashMap<String, String>,
pub common: Option<CommonLanguageSettings>,
}The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Settings for Java client libraries.
Fields
library_package: StringThe opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
The package name to use in Java. Clobbers the java_package option set in the protobuf. This should be used only by APIs who have already set the language_settings.java.package_nameโ field in gapic.yaml. API teams should use the protobuf java_package option where possible.
Example of a YAML configuration::
publishing: java_settings: library_package: com.google.cloud.pubsub.v1
service_class_names: HashMap<String, String>The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Configure the Java class name to use instead of the serviceโs for its corresponding generated GAPIC client. Keys are fully-qualified service names as they appear in the protobuf (including the full the language_settings.java.interface_namesโ field in gapic.yaml. API teams should otherwise use the service name as it appears in the protobuf.
Example of a YAML configuration::
publishing: java_settings: service_class_names: - google.pubsub.v1.Publisher: TopicAdmin - google.pubsub.v1.Subscriber: SubscriptionAdmin
common: Option<CommonLanguageSettings>The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Some settings.