pub struct MethodSettings {
pub selector: String,
pub long_running: Option<LongRunning>,
pub auto_populated_fields: Vec<String>,
}The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Describes the generator configuration for a method.
Fields
selector: StringThe opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
The fully qualified name of the method, for which the options below apply. This is used to find the method to apply the options.
Example:
publishing:
method_settings:
- selector: google.storage.control.v2.StorageControl.CreateFolderlong_running: Option<LongRunning>The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Describes settings to use for long-running operations when generating API methods for RPCs. Complements RPCs that use the annotations in google/longrunning/operations.proto.
Example of a YAML configuration::
publishing:
method_settings:
- selector: google.cloud.speech.v2.Speech.BatchRecognize
long_running:
initial_poll_delay: 60s # 1 minute
poll_delay_multiplier: 1.5
max_poll_delay: 360s # 6 minutes
total_poll_timeout: 54000s # 90 minutesauto_populated_fields: Vec<String>The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
List of top-level fields of the request message, that should be automatically populated by the client libraries based on their (google.api.field_info).format. Currently supported format: UUID4.
Example of a YAML configuration:
publishing:
method_settings:
- selector: google.example.v1.ExampleService.CreateExample
auto_populated_fields:
- request_idTrait Implementations
Sourceimpl Clone for MethodSettings
impl Clone for MethodSettings
Sourcefn clone(&self) -> MethodSettings
fn clone(&self) -> MethodSettings
1.0.0 (const: unstable) ยท Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for MethodSettings
impl Debug for MethodSettings
Sourceimpl Default for MethodSettings
impl Default for MethodSettings
Sourceimpl Message for MethodSettings
impl Message for MethodSettings
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Sourcefn encode_to_vec(&self) -> Vec<u8> โwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> โwhere
Self: Sized,
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> โwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> โwhere
Self: Sized,
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
self.Sourceimpl PartialEq for MethodSettings
impl PartialEq for MethodSettings
impl StructuralPartialEq for MethodSettings