pub struct ResourceReference {
pub type: String,
pub child_type: String,
}The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Defines a proto annotation that describes a string field that refers to an API resource.
Fields
type: StringThe opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
The resource type that the annotated field references.
Example:
message Subscription {
string topic = 2 [(google.api.resource_reference) = {
type: "pubsub.googleapis.com/Topic"
}];
}Occasionally, a field may reference an arbitrary resource. In this case, APIs use the special value * in their resource reference.
Example:
message GetIamPolicyRequest {
string resource = 2 [(google.api.resource_reference) = {
type: "*"
}];
}child_type: StringThe opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
The resource type of a child collection that the annotated field
references. This is useful for annotating the parent field that
doesnโt have a fixed resource type.
Example:
message ListLogEntriesRequest {
string parent = 1 [(google.api.resource_reference) = {
child_type: "logging.googleapis.com/LogEntry"
};
}Trait Implementations
Sourceimpl Clone for ResourceReference
impl Clone for ResourceReference
Sourcefn clone(&self) -> ResourceReference
fn clone(&self) -> ResourceReference
1.0.0 (const: unstable) ยท Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ResourceReference
impl Debug for ResourceReference
Sourceimpl Default for ResourceReference
impl Default for ResourceReference
Sourceimpl Message for ResourceReference
impl Message for ResourceReference
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Sourcefn encode_to_vec(&self) -> Vec<u8> โwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> โwhere
Self: Sized,
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> โwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> โwhere
Self: Sized,
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
self.Sourceimpl PartialEq for ResourceReference
impl PartialEq for ResourceReference
impl StructuralPartialEq for ResourceReference