Module v2

👎Deprecated since 0.30.0:

The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.

Modules

attribute_valueDeprecated
Nested message and enum types in AttributeValue.
spanDeprecated
Nested message and enum types in Span.
stack_traceDeprecated
Nested message and enum types in StackTrace.
trace_service_clientDeprecated
Generated client implementations.

Structs

AttributeValueDeprecated
The allowed types for \[VALUE\] in a \[KEY\]:[VALUE] attribute.
BatchWriteSpansRequestDeprecated
The request message for the BatchWriteSpans method.
ModuleDeprecated
Binary module.
SpanDeprecated
A span represents a single operation within a trace. Spans can be nested to form a trace tree. Often, a trace contains a root span that describes the end-to-end latency, and one or more subspans for its sub-operations.
StackTraceDeprecated
A call stack appearing in a trace.
TruncatableStringDeprecated
Represents a string that might be shortened to a specified length.