👎Deprecated since 0.30.0:
The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Nested message and enum types in Span.
Modules
- link
Deprecated - Nested message and enum types in
Link. - time_
event Deprecated - Nested message and enum types in
TimeEvent.
Structs
- Attributes
Deprecated - A set of attributes as key-value pairs.
- Link
Deprecated - A pointer from the current span to another span in the same trace or in a different trace. For example, this can be used in batching operations, where a single batch handler processes multiple requests from different traces or when the handler receives a request from a different project.
- Links
Deprecated - A collection of links, which are references from this span to a span in the same or different trace.
- Time
Event Deprecated - A time-stamped annotation or message event in the Span.
- Time
Events Deprecated - A collection of
TimeEvents. ATimeEventis a time-stamped annotation on the span, consisting of either user-supplied key:value pairs, or details of a message sent/received between Spans.
Enums
- Span
Kind Deprecated - Type of span. Can be used to specify additional relationships between spans in addition to a parent/child relationship.