Module time_event

Module time_event 

👎Deprecated since 0.30.0:

The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.

Nested message and enum types in TimeEvent.

Modules

message_eventDeprecated
Nested message and enum types in MessageEvent.

Structs

AnnotationDeprecated
Text annotation with a set of attributes.
MessageEventDeprecated
An event describing a message sent/received between Spans.

Enums

ValueDeprecated
A TimeEvent can contain either an Annotation object or a MessageEvent object, but not both.