Module stack_trace

Module stack_trace 

๐Ÿ‘ŽDeprecated since 0.30.0:

The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.

Nested message and enum types in StackTrace.

Structs

StackFrameDeprecated
Represents a single stack frame in a stack trace.
StackFramesDeprecated
A collection of stack frames, which can be truncated.