pub struct BatchWriteSpansRequest {
pub name: String,
pub spans: Vec<Span>,
}The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
The request message for the BatchWriteSpans method.
Fields
name: StringThe opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Required. The name of the project where the spans belong. The format is
projects/\[PROJECT_ID\].
spans: Vec<Span>The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Required. A list of new spans. The span names must not match existing spans, otherwise the results are undefined.