pub struct StackTrace {
pub stack_frames: Option<StackFrames>,
pub stack_trace_hash_id: i64,
}The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
A call stack appearing in a trace.
Fields
stack_frames: Option<StackFrames>The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Stack frames in this stack trace. A maximum of 128 frames are allowed.
stack_trace_hash_id: i64The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
The hash ID is used to conserve network bandwidth for duplicate stack traces within a single trace.
Often multiple spans will have identical stack traces.
The first occurrence of a stack trace should contain both the
stackFrame content and a value in stackTraceHashId.
Subsequent spans within the same request can refer
to that stack trace by only setting stackTraceHashId.