Module v2

Module v2 

👎Deprecated since 0.30.0:

The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.

Modules

log_entryDeprecated
Nested message and enum types in LogEntry.
logging_service_v2_clientDeprecated
Generated client implementations.
tail_log_entries_responseDeprecated
Nested message and enum types in TailLogEntriesResponse.

Structs

DeleteLogRequestDeprecated
The parameters to DeleteLog.
ListLogEntriesRequestDeprecated
The parameters to ListLogEntries.
ListLogEntriesResponseDeprecated
Result returned from ListLogEntries.
ListLogsRequestDeprecated
The parameters to ListLogs.
ListLogsResponseDeprecated
Result returned from ListLogs.
ListMonitoredResourceDescriptorsRequestDeprecated
The parameters to ListMonitoredResourceDescriptors
ListMonitoredResourceDescriptorsResponseDeprecated
Result returned from ListMonitoredResourceDescriptors.
LogEntryDeprecated
An individual entry in a log.
LogEntryOperationDeprecated
Additional information about a potentially long-running operation with which a log entry is associated.
LogEntrySourceLocationDeprecated
Additional information about the source code location that produced the log entry.
LogSplitDeprecated
Additional information used to correlate multiple log entries. Used when a single LogEntry would exceed the Google Cloud Logging size limit and is split across multiple log entries.
TailLogEntriesRequestDeprecated
The parameters to TailLogEntries.
TailLogEntriesResponseDeprecated
Result returned from TailLogEntries.
WriteLogEntriesPartialErrorsDeprecated
Error details for WriteLogEntries with partial success.
WriteLogEntriesRequestDeprecated
The parameters to WriteLogEntries.
WriteLogEntriesResponseDeprecated
Result returned from WriteLogEntries.