pub struct DeleteLogRequest {
pub log_name: String,
}The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
The parameters to DeleteLog.
Fields
log_name: StringThe opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Required. The resource name of the log to delete:
projects/\[PROJECT_ID\]/logs/\[LOG_ID\]organizations/\[ORGANIZATION_ID\]/logs/\[LOG_ID\]billingAccounts/\[BILLING_ACCOUNT_ID\]/logs/\[LOG_ID\]folders/\[FOLDER_ID\]/logs/\[LOG_ID\]
\[LOG_ID\] must be URL-encoded. For example,
"projects/my-project-id/logs/syslog",
"organizations/123/logs/cloudaudit.googleapis.com%2Factivity".
For more information about log names, see [LogEntry][google.logging.v2.LogEntry].