pub struct ListLogEntriesRequest {
pub resource_names: Vec<String>,
pub filter: String,
pub order_by: String,
pub page_size: i32,
pub page_token: String,
}The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
The parameters to ListLogEntries.
Fields
resource_names: Vec<String>The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Required. Names of one or more parent resources from which to retrieve log entries:
projects/\[PROJECT_ID\]organizations/\[ORGANIZATION_ID\]billingAccounts/\[BILLING_ACCOUNT_ID\]folders/\[FOLDER_ID\]
May alternatively be one or more views:
projects/\[PROJECT_ID\]/locations/\[LOCATION_ID\]/buckets/\[BUCKET_ID\]/views/\[VIEW_ID\]organizations/\[ORGANIZATION_ID\]/locations/\[LOCATION_ID\]/buckets/\[BUCKET_ID\]/views/\[VIEW_ID\]billingAccounts/\[BILLING_ACCOUNT_ID\]/locations/\[LOCATION_ID\]/buckets/\[BUCKET_ID\]/views/\[VIEW_ID\]folders/\[FOLDER_ID\]/locations/\[LOCATION_ID\]/buckets/\[BUCKET_ID\]/views/\[VIEW_ID\]
Projects listed in the project_ids field are added to this list.
A maximum of 100 resources may be specified in a single request.
filter: StringThe opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Optional. Only log entries that match the filter are returned. An empty
filter matches all log entries in the resources listed in resource_names.
Referencing a parent resource that is not listed in resource_names will
cause the filter to return no results. The maximum length of a filter is
20,000 characters.
order_by: StringThe opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Optional. How the results should be sorted. Presently, the only permitted
values are "timestamp asc" (default) and "timestamp desc". The first
option returns entries in order of increasing values of
LogEntry.timestamp (oldest first), and the second option returns entries
in order of decreasing timestamps (newest first). Entries with equal
timestamps are returned in order of their insert_id values.
page_size: i32The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Optional. The maximum number of results to return from this request.
Default is 50. If the value is negative or exceeds 1000, the request is
rejected. The presence of next_page_token in the response indicates that
more results might be available.
page_token: StringThe opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Optional. If present, then retrieve the next batch of results from the
preceding call to this method. page_token must be the value of
next_page_token from the previous response. The values of other method
parameters should be identical to those in the previous call.