pub struct ListLogEntriesResponse {
pub entries: Vec<LogEntry>,
pub next_page_token: String,
}The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Result returned from ListLogEntries.
Fields
entries: Vec<LogEntry>The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
A list of log entries. If entries is empty, nextPageToken may still be
returned, indicating that more entries may exist. See nextPageToken for
more information.
next_page_token: StringThe opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
If there might be more results than those appearing in this response, then
nextPageToken is included. To get the next set of results, call this
method again using the value of nextPageToken as pageToken.
If a value for next_page_token appears and the entries field is empty,
it means that the search found no log entries so far but it did not have
time to search all the possible log entries. Retry the method with this
value for page_token to continue the search. Alternatively, consider
speeding up the search by changing your filter to specify a single log name
or resource type, or to narrow the time range of the search.