pub struct ListMonitoredResourceDescriptorsRequest {
pub page_size: i32,
pub page_token: String,
}The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
The parameters to ListMonitoredResourceDescriptors
Fields
page_size: i32The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Optional. The maximum number of results to return from this request.
Non-positive values are ignored. The presence of nextPageToken in the
response indicates that more results might be available.
page_token: StringThe opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Optional. If present, then retrieve the next batch of results from the
preceding call to this method. pageToken must be the value of
nextPageToken from the previous response. The values of other method
parameters should be identical to those in the previous call.