pub struct ListMonitoredResourceDescriptorsResponse {
pub resource_descriptors: Vec<MonitoredResourceDescriptor>,
pub next_page_token: String,
}The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Result returned from ListMonitoredResourceDescriptors.
Fields
resource_descriptors: Vec<MonitoredResourceDescriptor>The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
A list of resource descriptors.
next_page_token: StringThe opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
If there might be more results than those appearing in this response, then
nextPageToken is included. To get the next set of results, call this
method again using the value of nextPageToken as pageToken.