pub struct WriteLogEntriesPartialErrors {
pub log_entry_errors: HashMap<i32, Status>,
}The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Error details for WriteLogEntries with partial success.
Fields
log_entry_errors: HashMap<i32, Status>The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
When WriteLogEntriesRequest.partial_success is true, records the error
status for entries that were not written due to a permanent error, keyed
by the entryโs zero-based index in WriteLogEntriesRequest.entries.
Failed requests for which no entries are written will not include per-entry errors.