WriteLogEntriesRequest

Struct WriteLogEntriesRequest 

pub struct WriteLogEntriesRequest {
    pub log_name: String,
    pub resource: Option<MonitoredResource>,
    pub labels: HashMap<String, String>,
    pub entries: Vec<LogEntry>,
    pub partial_success: bool,
    pub dry_run: bool,
}
๐Ÿ‘ŽDeprecated since 0.30.0:

The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.

The parameters to WriteLogEntries.

Fields

log_name: String
๐Ÿ‘ŽDeprecated since 0.30.0:

The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.

Optional. A default log resource name that is assigned to all log entries in entries that do not specify a value for log_name:

  • projects/\[PROJECT_ID\]/logs/\[LOG_ID\]
  • organizations/\[ORGANIZATION_ID\]/logs/\[LOG_ID\]
  • billingAccounts/\[BILLING_ACCOUNT_ID\]/logs/\[LOG_ID\]
  • folders/\[FOLDER_ID\]/logs/\[LOG_ID\]

\[LOG_ID\] must be URL-encoded. For example:

 "projects/my-project-id/logs/syslog"
 "organizations/123/logs/cloudaudit.googleapis.com%2Factivity"

The permission logging.logEntries.create is needed on each project, organization, billing account, or folder that is receiving new log entries, whether the resource is specified in logName or in an individual log entry.

resource: Option<MonitoredResource>
๐Ÿ‘ŽDeprecated since 0.30.0:

The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.

Optional. A default monitored resource object that is assigned to all log entries in entries that do not specify a value for resource. Example:

 { "type": "gce_instance",
   "labels": {
     "zone": "us-central1-a", "instance_id": "00000000000000000000" }}

See [LogEntry][google.logging.v2.LogEntry].

labels: HashMap<String, String>
๐Ÿ‘ŽDeprecated since 0.30.0:

The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.

Optional. Default labels that are added to the labels field of all log entries in entries. If a log entry already has a label with the same key as a label in this parameter, then the log entryโ€™s label is not changed. See [LogEntry][google.logging.v2.LogEntry].

entries: Vec<LogEntry>
๐Ÿ‘ŽDeprecated since 0.30.0:

The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.

Required. The log entries to send to Logging. The order of log entries in this list does not matter. Values supplied in this methodโ€™s log_name, resource, and labels fields are copied into those log entries in this list that do not include values for their corresponding fields. For more information, see the [LogEntry][google.logging.v2.LogEntry] type.

If the timestamp or insert_id fields are missing in log entries, then this method supplies the current time or a unique identifier, respectively. The supplied values are chosen so that, among the log entries that did not supply their own values, the entries earlier in the list will sort before the entries later in the list. See the entries.list method.

Log entries with timestamps that are more than the logs retention period in the past or more than 24 hours in the future will not be available when calling entries.list. However, those log entries can still be exported with LogSinks.

To improve throughput and to avoid exceeding the quota limit for calls to entries.write, you should try to include several log entries in this list, rather than calling this method for each individual log entry.

partial_success: bool
๐Ÿ‘ŽDeprecated since 0.30.0:

The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.

Optional. Whether a batchโ€™s valid entries should be written even if some other entry failed due to a permanent error such as INVALID_ARGUMENT or PERMISSION_DENIED. If any entry failed, then the response status is the response status of one of the failed entries. The response will include error details in WriteLogEntriesPartialErrors.log_entry_errors keyed by the entriesโ€™ zero-based index in the entries. Failed requests for which no entries are written will not include per-entry errors.

dry_run: bool
๐Ÿ‘ŽDeprecated since 0.30.0:

The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.

Optional. If true, the request should expect normal response, but the entries wonโ€™t be persisted nor exported. Useful for checking whether the logging API endpoints are working properly before sending valuable data.