👎Deprecated since 0.30.0:
The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Modules
- http_
rule Deprecated - Nested message and enum types in
HttpRule. - label_
descriptor Deprecated - Nested message and enum types in
LabelDescriptor. - method_
settings Deprecated - Nested message and enum types in
MethodSettings. - python_
settings Deprecated - Nested message and enum types in
PythonSettings. - resource_
descriptor Deprecated - Nested message and enum types in
ResourceDescriptor.
Structs
- Client
Library Settings Deprecated - Details about how and where to publish client libraries.
- Common
Language Settings Deprecated - Required information for every language.
- CppSettings
Deprecated - Settings for C++ client libraries.
- Custom
Http Pattern Deprecated - A custom pattern is used for defining custom HTTP verb.
- Dotnet
Settings Deprecated - Settings for Dotnet client libraries.
- GoSettings
Deprecated - Settings for Go client libraries.
- Http
Deprecated - Defines the HTTP configuration for an API service. It contains a list of [HttpRule][google.api.HttpRule], each specifying the mapping of an RPC method to one or more HTTP REST API methods.
- Http
Rule Deprecated - gRPC Transcoding
- Java
Settings Deprecated - Settings for Java client libraries.
- Label
Descriptor Deprecated - A description of a label.
- Method
Settings Deprecated - Describes the generator configuration for a method.
- Monitored
Resource Deprecated - An object representing a resource that can be used for monitoring, logging,
billing, or other purposes. Examples include virtual machine instances,
databases, and storage devices such as disks. The
typefield identifies a [MonitoredResourceDescriptor][google.api.MonitoredResourceDescriptor] object that describes the resource’s schema. Information in thelabelsfield identifies the actual resource and its attributes according to the schema. For example, a particular Compute Engine VM instance could be represented by the following object, because the [MonitoredResourceDescriptor][google.api.MonitoredResourceDescriptor] for"gce_instance"has labels"project_id","instance_id"and"zone": - Monitored
Resource Descriptor Deprecated - An object that describes the schema of a
[MonitoredResource][google.api.MonitoredResource] object using a type name
and a set of labels. For example, the monitored resource descriptor for
Google Compute Engine VM instances has a type of
"gce_instance"and specifies the use of the labels"instance_id"and"zone"to identify particular VM instances. - Monitored
Resource Metadata Deprecated - Auxiliary metadata for a [MonitoredResource][google.api.MonitoredResource] object. [MonitoredResource][google.api.MonitoredResource] objects contain the minimum set of information to uniquely identify a monitored resource instance. There is some other useful auxiliary metadata. Monitoring and Logging use an ingestion pipeline to extract metadata for cloud resources of all types, and store the metadata in this message.
- Node
Settings Deprecated - Settings for Node client libraries.
- PhpSettings
Deprecated - Settings for Php client libraries.
- Publishing
Deprecated - This message configures the settings for publishing Google Cloud Client libraries generated from the service config.
- Python
Settings Deprecated - Settings for Python client libraries.
- Resource
Descriptor Deprecated - A simple descriptor of a resource type.
- Resource
Reference Deprecated - Defines a proto annotation that describes a string field that refers to an API resource.
- Ruby
Settings Deprecated - Settings for Ruby client libraries.
- Selective
Gapic Generation Deprecated - This message is used to configure the generation of a subset of the RPCs in a service for client libraries.
Enums
- Client
Library Destination Deprecated - To where should client libraries be published?
- Client
Library Organization Deprecated - The organization for which the client libraries are being published. Affects the url where generated docs are published, etc.
- Field
Behavior Deprecated - An indicator of the behavior of a given field (for example, that a field is required in requests, or given as output but ignored as input). This does not change the behavior in protocol buffers itself; it only denotes the behavior and may affect how API tooling handles the field.
- Launch
Stage Deprecated - The launch stage as defined by Google Cloud Platform Launch Stages.