๐Deprecated since 0.30.0:
The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Nested message and enum types in PythonSettings.
Structs
- Experimental
Features Deprecated - Experimental features to be included during client library generation. These fields will be deprecated once the feature graduates and is enabled by default.