👎Deprecated since 0.30.0:
The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Modules
- attribute_
value Deprecated - Nested message and enum types in
AttributeValue. - span
Deprecated - Nested message and enum types in
Span. - stack_
trace Deprecated - Nested message and enum types in
StackTrace. - trace_
service_ client Deprecated - Generated client implementations.
Structs
- Attribute
Value Deprecated - The allowed types for
\[VALUE\]in a\[KEY\]:[VALUE]attribute. - Batch
Write Spans Request Deprecated - The request message for the
BatchWriteSpansmethod. - Module
Deprecated - Binary module.
- Span
Deprecated - A span represents a single operation within a trace. Spans can be nested to form a trace tree. Often, a trace contains a root span that describes the end-to-end latency, and one or more subspans for its sub-operations.
- Stack
Trace Deprecated - A call stack appearing in a trace.
- Truncatable
String Deprecated - Represents a string that might be shortened to a specified length.