๐Deprecated since 0.30.0:
The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Nested message and enum types in Link.
Enums
- Type
Deprecated - The relationship of the current span relative to the linked span: child, parent, or unspecified.