๐Deprecated since 0.30.0:
The opentelemetry-stackdriver crate is deprecated and will be removed from opentelemetry-rust-contrib. Migrate to OTLP (Google Cloud supports OTLP ingestion, and the OpenTelemetry Collector ships a googlecloud exporter). See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Generated client implementations.
Structs
- Trace
Service Client Deprecated - Service for collecting and viewing traces and spans within a trace.